@@ -19,13 +19,17 @@ L<http://www.w3c.org/Graphics/SVG/> SVG at the W3C
 
 package SVG::XML;
 use strict;
+use warnings;
+
 use vars qw($VERSION @ISA @EXPORT );
 
-$VERSION = "2.26";
+$VERSION = "2.44";
 
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(
+    xmlesc
+    xmlescape
     xmlescp
     cssstyle
     xmlattrib
@@ -59,6 +63,10 @@ sub xmlescp ($) {
     return $s;
 }
 
+*xmlesc=\&xmlescp;
+
+*xmlescape=\&xmlescp;
+
 sub cssstyle {
     my %attrs=@_;
     return(join('; ',map { qq($_: ).$attrs{$_} } keys(%attrs)));
